#!/usr/bin/env python

import re
import os
from pathlib import Path

from lulu.common import (
    match1,
    url_info,
    print_info,
    get_content,
    download_urls,
)
from lulu.util.parser import get_parser


__all__ = ['douban_download']
site_info = '豆瓣 douban.com'


def douban_download(
    url, output_dir='.', merge=True, info_only=False, **kwargs
):
    html = get_content(url)
    parser = get_parser(html)

    if re.match(r'https?://movie', url):
        title = ' '.join(
            [string.strip() for string in parser.h1.strings]
        )
        tid = match1(url, 'trailer/(\d+)')
        real_url = 'https://movie.douban.com/trailer/video_url?tid={}'.format(
            tid
        )
        _type, ext, size = url_info(real_url)

        print_info(site_info, title, _type, size)
        if not info_only:
            download_urls(
                [real_url], title, ext, size, output_dir, merge=merge
            )


def douban_download_playlist(url, output_dir='.', **kwargs):
    html = get_content(url)
    parser = get_parser(html)
    video_dir = Path(output_dir) / parser.h1.a.text
    if not kwargs['info_only']:
        if not video_dir.exists():
            os.mkdir(video_dir)
    urls = parser.find_all('a', class_='pr-video')
    for url in urls:
        douban_download(url['href'], output_dir=video_dir, **kwargs)


download = douban_download
download_playlist = douban_download_playlist



#!/usr/bin/env python

import re
import ssl
from urllib import request

from lulu.common import (
    match1,
    url_info,
    print_info,
    get_content,
    download_urls,
    playlist_not_supported,
)


__all__ = ['videomega_download']
site_info = 'Videomega.tv'


def videomega_download(url, info_only=False, **kwargs):
    # Hot-plug cookie handler
    ssl_context = request.HTTPSHandler(
        context=ssl.SSLContext(ssl.PROTOCOL_TLSv1)
    )
    cookie_handler = request.HTTPCookieProcessor()
    opener = request.build_opener(ssl_context, cookie_handler)
    opener.addheaders = [('Referer', url), ('Cookie', 'noadvtday=0')]
    request.install_opener(opener)

    if re.search(r'view\.php', url):
        php_url = url
    else:
        content = get_content(url)
        m = re.search(
            r'ref="([^"]*)";\s*width="([^"]*)";\s*height="([^"]*)"', content
        )
        ref = m.group(1)
        width, height = m.group(2), m.group(3)
        php_url = (
            'http://videomega.tv/view.php?ref={}&width={}&height={}'.format(
                ref, width, height
            )
        )
    content = get_content(php_url)

    title = match1(content, r'<title>(.*)</title>')
    js = match1(content, r'(eval.*)')
    t = match1(js, r'\$\("\w+"\)\.\w+\("\w+","([^"]+)"\)')
    t = re.sub(r'(\w)', r'{\1}', t)
    t = t.translate({87 + i: str(i) for i in range(10, 36)})
    s = match1(js, r"'([^']+)'\.split").split('|')
    src = t.format(*s)

    _type, ext, size = url_info(src, faker=True)

    print_info(site_info, title, _type, size)
    if not info_only:
        download_urls([src], title, ext, size, **kwargs)


download = videomega_download
download_playlist = playlist_not_supported(site_info)



#!/usr/bin/env python

import json

from lulu.common import (
    match1,
    get_content,
    playlist_not_supported,
)
from lulu.extractors.youku import youku_download_by_vid


__all__ = ['tudou_download']
site_info = '土豆 tudou.com'


def tudou_download(url, **kwargs):
    if 'video.tudou.com' in url:
        vid = match1(url, r'.*?video.tudou.com/v/([\w=]+)')
    else:
        page = get_content(url)
        video_info = json.loads(
            match1(page, r'window.__INITIAL_STATE__=\s*(.+?);</script>')
        )
        vid = video_info['videoDesc']['detail']['videoid']
    youku_download_by_vid(vid, **kwargs)


download = tudou_download
download_playlist = playlist_not_supported(site_info)



#!/usr/bin/env python

import re
from urllib import parse
from html import unescape

from lulu.extractors.vine import vine_download
from lulu.extractors.vimeo import vimeo_download
from lulu.extractors.universal import universal_download
from lulu.extractors.dailymotion import dailymotion_download

from lulu.common import (
    match1,
    url_info,
    url_size,
    print_info,
    get_content,
    download_urls,
    playlist_not_supported,
)


__all__ = ['tumblr_download']
site_info = 'Tumblr.com'


def tumblr_download(
    url, output_dir='.', merge=True, info_only=False, **kwargs
):
    if re.match(r'https?://\d+\.media\.tumblr\.com/', url):
        universal_download(url, output_dir, merge=merge, info_only=info_only)
        return

    html = parse.unquote(get_content(url)).replace('\/', '/')
    feed = match1(
        html, r'<meta property="og:type" content="tumblr-feed:(\w+)" />'
    )

    if feed in ['photo', 'photoset', 'entry'] or feed is None:
        # try to extract photos
        page_title = match1(
            html, r'<meta name="description" content="([^"\n]+)'
        ) or match1(
            html, r'<meta property="og:description" content="([^"\n]+)'
        ) or match1(html, r'<title>([^<\n]*)')
        urls = re.findall(
            r'(https?://[^;"&]+/tumblr_[^;"]+_\d+\.jpg)', html
        ) + re.findall(
            r'(https?://[^;"&]+/tumblr_[^;"]+_\d+\.png)', html
        ) + re.findall(r'(https?://[^;"&]+/tumblr_[^";]+_\d+\.gif)', html)

        tuggles = {}
        for url in urls:
            filename = parse.unquote(url.split('/')[-1])
            title = '.'.join(filename.split('.')[:-1])
            tumblr_id = match1(title, r'^tumblr_(.+)_\d+$')
            quality = int(match1(title, r'^tumblr_.+_(\d+)$'))
            ext = filename.split('.')[-1]
            try:
                size = url_size(url)
                if tumblr_id not in tuggles or tuggles[tumblr_id]['quality'] \
                        < quality:
                    tuggles[tumblr_id] = {
                        'title': title,
                        'url': url,
                        'quality': quality,
                        'ext': ext,
                        'size': size,
                    }
            except Exception:
                pass

        if tuggles:
            size = sum([tuggles[t]['size'] for t in tuggles])
            print_info(site_info, page_title, None, size)

            if not info_only:
                for t in tuggles:
                    title = tuggles[t]['title']
                    ext = tuggles[t]['ext']
                    size = tuggles[t]['size']
                    url = tuggles[t]['url']
                    print_info(site_info, title, ext, size)
                    download_urls(
                        [url], title, ext, size, output_dir=output_dir
                    )
            return

    # feed == 'audio' or feed == 'video' or feed is None
    # try to extract video / audio
    real_url = match1(html, r'source src=\\x22([^\\]+)\\')
    if not real_url:
        real_url = match1(html, r'audio_file=([^&]+)&')
        if real_url:
            real_url = (
                '{}?plead=please-dont-download-this-or-our-lawyers-wont-let-us'
                '-host-audio'.format(real_url)
            )
    if not real_url:
        real_url = match1(html, r'<source src="([^"]*)"')
    if not real_url:
        iframe_url = match1(
            html,
            r'<[^>]+tumblr_video_container[^>]+><iframe[^>]+'
            r'src=[\'"]([^\'"]*)[\'"]'
        )
        if iframe_url:
            iframe_html = get_content(iframe_url)
            real_url = match1(
                iframe_html,
                r'<video[^>]*>[\n ]*<source[^>]+src=[\'"]([^\'"]*)[\'"]'
            )
        else:
            iframe_url = match1(html, r'<iframe[^>]+src=[\'"]([^\'"]*)[\'"]')
            if iframe_url[:2] == '//':
                iframe_url = 'http:' + iframe_url
            if re.search(r'player\.vimeo\.com', iframe_url):
                vimeo_download(
                    iframe_url, output_dir, merge=merge, info_only=info_only,
                    referer='http://tumblr.com/', **kwargs
                )
                return
            elif re.search(r'dailymotion\.com', iframe_url):
                dailymotion_download(
                    iframe_url, output_dir, merge=merge, info_only=info_only,
                    **kwargs
                )
                return
            elif re.search(r'vine\.co', iframe_url):
                vine_download(
                    iframe_url, output_dir, merge=merge, info_only=info_only,
                    **kwargs
                )
                return
            else:
                iframe_html = get_content(iframe_url)
                real_url = match1(iframe_html, r'<source src="([^"]*)"')

    title = unescape(
        match1(
            html, r'<meta property="og:title" content="([^"]*)" />'
        ) or match1(
            html, r'<meta property="og:description" content="([^"]*)" />'
        ) or match1(html, r'<title>([^<\n]*)') or url.split('/')[4]
    ).replace('\n', '')

    _type, ext, size = url_info(real_url)

    print_info(site_info, title, _type, size)
    if not info_only:
        download_urls([real_url], title, ext, size, output_dir, merge=merge)


download = tumblr_download
download_playlist = playlist_not_supported(site_info)



#!/usr/bin/env python

import re
import json

from lulu.common import (
    match1,
    url_info,
    print_info,
    get_content,
    post_content,
    download_urls,
    playlist_not_supported,
)


__all__ = ['vk_download']
site_info = 'VK vk.com'


def get_video_info(url):
    ep = 'https://vk.com/al_video.php'
    to_post = dict(
        act='show', al=1, module='direct',
        video=re.search(r'video(-\d+_\d+)', url).group(1)
    )
    page = post_content(ep, post_data=to_post)
    video_pt = r'<source src="(.+?)" type="video\/mp4"'
    url = re.search(video_pt, page).group(1)
    title = re.search(r'<div class="mv_title".+?>(.+?)</div>', page).group(1)
    mime, ext, size = url_info(url)
    print_info(site_info, title, mime, size)

    return url, title, ext, size


def get_image_info(url):
    image_page = get_content(url)
    photo_id = url.split('-')[-1]
    photo_data = json.loads(
        match1(image_page, r'({{"id":"-{}.+?}}),'.format(photo_id))
    )
    for quality in ['z_src', 'y_src', 'x_src', 'r_src', 'q_src', 'p_src']:
        if photo_data.get(quality):
            image_link = photo_data[quality]
            break
    title = image_link.split('/')[-1].split('.')[0]
    _type, ext, size = url_info(image_link)
    print_info(site_info, title, _type, size)

    return image_link, title, ext, size


def vk_download(
    url, output_dir='.', stream_type=None, merge=True, info_only=False,
    **kwargs
):
    link = None
    if re.match(r'(.+)vk\.com\/video(.+)', url):
        link, title, ext, size = get_video_info(url)
    elif re.match(r'(.+)vk\.com\/photo(.+)', url):
        link, title, ext, size = get_image_info(url)
    else:
        raise NotImplementedError('Nothing to download here')

    if not info_only and link is not None:
        download_urls([link], title, ext, size, output_dir, merge=merge)


download = vk_download
download_playlist = playlist_not_supported(site_info)



#!/usr/bin/env python

import json

from lulu.common import (
    match1,
    get_content,
    playlist_not_supported,
)
from lulu.extractors.theplatform import theplatform_download_by_pid


__all__ = ['cbs_download']
site_info = 'CBS cbs.com'


def cbs_download(url, output_dir='.', merge=True, info_only=False, **kwargs):
    """Downloads CBS videos by URL.
    """
    html = get_content(url)
    data = json.loads(match1(html, r'var \$module = (.+);'))
    pid = data['video']['pid']
    title = data['video']['title']
    theplatform_download_by_pid(
        pid, title, output_dir=output_dir, merge=merge, info_only=info_only
    )


download = cbs_download
download_playlist = playlist_not_supported(site_info)



import re
import json
from html import unescape

from lulu.util import log
from lulu.common import get_content
from lulu.extractor import VideoExtractor


__all__ = ['qq_egame_download']


class QQEgame(VideoExtractor):
    stream_types = [
        {'id': '1080p', 'video_profile': 0, 'container': 'flv'},
        {'id': '720p', 'video_profile': 3000, 'container': 'flv'},
        {'id': '540p', 'video_profile': 1500, 'container': 'flv'}
    ]
    name = '企鹅电竞 egame.qq.com'

    def prepare(self, **kwargs):
        page = get_content(self.url)
        server_data = re.search(r'window\.__NUXT__=({.+?});', page)
        if server_data is None:
            log.wtf('cannot find server_data')
        json_data = json.loads(server_data.group(1))['state']
        live_info = json_data['live-info']['liveInfo']
        self.title = '{}_{}'.format(
            json_data['anchor-info']['anchorInfo']['nickName'],
            live_info['videoInfo']['title']
        )
        for exsited_stream in live_info['videoInfo']['streamInfos']:
            for s in self.__class__.stream_types:
                if s['video_profile'] == exsited_stream['bitrate']:
                    current_stream_id = s['id']
                    stream_info = dict(
                        src=[unescape(exsited_stream['playUrl'])]
                    )
                    stream_info['video_profile'] = exsited_stream['desc']
                    stream_info['container'] = s['container']
                    stream_info['size'] = float('inf')
                    self.streams[current_stream_id] = stream_info


def qq_egame_download(url, **kwargs):
    QQEgame().download_by_url(url, **kwargs)
    # url dispatching has been done in qq.py



#!/usr/bin/env python

from lulu.common import (
    url_info,
    print_info,
    get_content,
    download_urls,
    playlist_not_supported,
)
from lulu.util.parser import get_parser


__all__ = ['archive_download']
site_info = 'Internet Archive archive.org'


def archive_download(url, merge=True, info_only=False, **kwargs):
    html = get_content(url)
    parser = get_parser(html)
    title = parser.find('meta', property='og:title')['content']
    source = parser.find('meta', property='og:video')['content']
    mime, ext, size = url_info(source)

    print_info(site_info, title, mime, size)
    if not info_only:
        download_urls([source], title, ext, size, merge=merge, **kwargs)


download = archive_download
download_playlist = playlist_not_supported(site_info)



#!/usr/bin/env python

from html import unescape
from xml.dom.minidom import parseString

from lulu.common import (
    match1,
    print_info,
    get_content,
    download_rtmp_url,
    playlist_not_supported,
)


__all__ = ['mtv81_download']
site_info = 'MTV 81 mtv81.com'


def mtv81_download(url, output_dir='.', merge=True, info_only=False, **kwargs):
    html = get_content(url)
    title = unescape(
        '|'.join(match1(html, r'<title>(.*?)</title>').split('|')[:-2])
    )

    # mgid%3Auma%3Avideo%3Amtv81.com%3A897974
    vid = match1(html, r'getTheVideo\("(.*?)"')
    xml = parseString(get_content(
        'http://intl.esperanto.mtvi.com/www/xml/media/mediaGen.jhtml?uri={}&'
        'flashPlayer=LNX%2013,0,0,206&geo=CN&sid=123456'.format(vid)
    ))

    url = sorted(
        map(lambda x: x.firstChild.nodeValue, xml.getElementsByTagName("src")),
        key=lambda x: int(match1(x, r'_(\d+?)_'))
    )[-1]

    mediatype, ext, size = 'mp4', 'mp4', 0
    print_info(site_info, title, mediatype, size)
    # rtmpdump  -r 'rtmpe://cp30865.edgefcs.net/ondemand/mtviestor/_!/intlod/MTVInternational/MBUS/GeoLocals/00JP/VIAMTVI/PYC/201304/7122HVAQ4/00JPVIAMTVIPYC7122HVAQ4_640x_360_1200_m30.mp4' -o "title.mp4" --swfVfy http://media.mtvnservices.com/player/prime/mediaplayerprime.1.10.8.swf  # noqa

    # because rtmpdump is unstable,may try serveral times
    if not info_only:
        download_rtmp_url(
            url=url, title=title, ext=ext, params={
                '--swfVfy': (
                    'http://media.mtvnservices.com/player/prime/mediaplayer'
                    'prime.1.10.8.swf'
                )
            }, output_dir=output_dir
        )


download = mtv81_download
download_playlist = playlist_not_supported(site_info)



#!/usr/bin/env python


from lulu.common import (
    url_info,
    print_info,
    get_content,
    download_urls,
    playlist_not_supported,
)
from lulu.util.parser import get_parser


__all__ = ['freesound_download']
site_info = 'Freesound freesound.org'


def freesound_download(
    url, output_dir='.', merge=True, info_only=False, **kwargs
):
    page = get_content(url)
    parser = get_parser(page)
    title = parser.find('meta', property='og:title')['content']
    preview_url = parser.find('meta', property='og:audio')['content']

    _type, ext, size = url_info(preview_url)

    print_info(site_info, title, _type, size)
    if not info_only:
        download_urls(
            [preview_url], title, ext, size, output_dir, merge=merge, **kwargs
        )


download = freesound_download
download_playlist = playlist_not_supported(site_info)



#!/usr/bin/env python

from lulu.common import (
    match1,
    url_info,
    get_content,
)
from lulu.extractor import VideoExtractor


class MusicPlayOn(VideoExtractor):
    name = 'MusicPlayOn musicplayon.com'

    stream_types = [
        {'id': '720p HD'},
        {'id': '360p SD'},
    ]

    def prepare(self, **kwargs):
        content = get_content(self.url)

        self.title = match1(
            content, r'setup\[\'title\'\] = "([^"]+)";'
        )

        for s in self.stream_types:
            quality = s['id']
            src = match1(
                content,
                r'src: "([^"]+)", "data-res": "{}"'.format(quality)
            )
            if src is not None:
                url = 'https://en.musicplayon.com{}'.format(src)
                self.streams[quality] = {'url': url}

    def extract(self, **kwargs):
        for i in self.streams:
            s = self.streams[i]
            _, s['container'], s['size'] = url_info(s['url'], faker=True)
            s['src'] = [s['url']]


site = MusicPlayOn()
download = site.download_by_url
# TBD: implement download_playlist



#!/usr/bin/env python

import json
import base64
import random
import binascii

from lulu.common import (
    match1,
    url_info,
    print_info,
    get_content,
    download_urls,
    playlist_not_supported,
)


__all__ = ['toutiao_download', ]
site_info = 'Toutiao.com'


def sign_video_url(vid):
    # some code from http://codecloud.net/110854.html
    r = str(random.random())[2:]

    def right_shift(val, n):
        return val >> n if val >= 0 else (val + 0x100000000) >> n

    url = 'http://i.snssdk.com/video/urls/v/1/toutiao/mp4/%s' % vid
    n = '{}?r={}'.format(
        url.replace('http://i.snssdk.com', ''), r
    )
    c = binascii.crc32(n.encode('ascii'))
    s = right_shift(c, 0)
    return '{}?r={}&s={}'.format(url, r, s)


class ToutiaoVideoInfo(object):

    def __init__(self):
        self.bitrate = None
        self.definition = None
        self.size = None
        self.height = None
        self.width = None
        self.type = None
        self.url = None

    def __str__(self):
        return json.dumps(self.__dict__)


def get_file_by_vid(video_id):
    vRet = []
    url = sign_video_url(video_id)
    ret = get_content(url)
    ret = json.loads(ret)
    vlist = ret.get('data').get('video_list')
    if len(vlist) > 0:
        vInfo = vlist.get(sorted(vlist.keys(), reverse=True)[0])
        vUrl = vInfo.get('main_url')
        vUrl = base64.decodestring(vUrl.encode('ascii')).decode('ascii')
        videoInfo = ToutiaoVideoInfo()
        videoInfo.bitrate = vInfo.get('bitrate')
        videoInfo.definition = vInfo.get('definition')
        videoInfo.size = vInfo.get('size')
        videoInfo.height = vInfo.get('vheight')
        videoInfo.width = vInfo.get('vwidth')
        videoInfo.type = vInfo.get('vtype')
        videoInfo.url = vUrl
        vRet.append(videoInfo)
    return vRet


def toutiao_download(url, info_only=False, **kwargs):
    html = get_content(url)
    video_id = match1(html, r"videoid\s*:\s*'([^']+)',\n")
    title = match1(html, r"title: '([^']+)'.replace")
    video_file_list = get_file_by_vid(video_id)  # 调api获取视频源文件
    _type, ext, size = url_info(video_file_list[0].url, faker=True)
    print_info(site_info=site_info, title=title, type=_type, size=size)
    if not info_only:
        download_urls([video_file_list[0].url], title, ext, size, **kwargs)


download = toutiao_download
download_playlist = playlist_not_supported(site_info)



#!/usr/bin/env python

import json

from lulu.common import (
    match1,
    url_info,
    get_content,
)
from lulu.extractor import VideoExtractor


class Pinterest(VideoExtractor):
    # site name
    name = 'Pinterest pinterest.com'

    # ordered list of supported stream types / qualities on this site
    # order: high quality -> low quality
    stream_types = [
        {'id': 'original'},  # contains an 'id' or 'itag' field at minimum
        {'id': 'small'},
    ]

    def prepare(self, **kwargs):
        # scrape the html
        content = get_content(self.url)
        # extract title
        self.title = match1(
            content,
            r'<meta property="og:description" name="og:description" '
            r'content="([^"]+)"'
        )

        data = match1(
            content,
            r'<script type="application/json" id=\'initial-state\'>(.+)'
            r'</script>'
        )
        data = json.loads(data)
        keys = list(data['resources']['data']['PinResource'].keys())
        orig_img = data['resources']['data']['PinResource'][keys[0]]['data'][
            'images'
        ]['orig']['url']
        twit_img = match1(
            content,
            r'<meta property="twitter:image:src" name="twitter:image:src" '
            r'content="([^"]+)"'
        )
        # construct available streams
        if orig_img:
            self.streams['original'] = {'url': orig_img}
        if twit_img:
            self.streams['small'] = {'url': twit_img}

    def extract(self, **kwargs):
        for i in self.streams:
            # for each available stream
            s = self.streams[i]
            # fill in 'container' field and 'size' field (optional)
            _, s['container'], s['size'] = url_info(s['url'])
            # 'src' field is a list of processed urls for direct downloading
            # usually derived from 'url'
            s['src'] = [s['url']]


site = Pinterest()
download = site.download_by_url
# TBD: implement download_playlist



#!/usr/bin/env python

import re

from lulu.common import (
    match1,
    url_info,
    print_info,
    get_content,
    download_urls,
)


__all__ = ['kuwo_download']
site_info = '酷我音乐 kuwo.cn'


def kuwo_download_by_rid(rid, info_only=False, **kwargs):
    html = get_content(
        'http://player.kuwo.cn/webmusic/st/getNewMuiseByRid?rid='
        'MUSIC_{}'.format(rid)
    )
    title = match1(html, r'<name>(.*)</name>')
    if not title:
        title = rid
    # format =aac|mp3 ->to get aac format=mp3 ->to get mp3
    url = get_content(
        'http://antiserver.kuwo.cn/anti.s?format=mp3&rid=MUSIC_{}&'
        'type=convert_url&response=url'.format(rid)
    )
    songtype, ext, size = url_info(url)
    print_info(site_info, title, songtype, size)
    if not info_only:
        download_urls([url], title, ext, size, **kwargs)


def kuwo_playlist_download(url, info_only=False, **kwargs):
    html = get_content(url)
    matched = set(re.compile('yinyue/(\d+)').findall(html))
    for rid in matched:
        kuwo_download_by_rid(rid, info_only, **kwargs)


def kuwo_download(url, info_only=False, **kwargs):
    if 'www.kuwo.cn/yinyue' in url:
        rid = match1(url, 'yinyue/(\d+)')
        kuwo_download_by_rid(rid, info_only, **kwargs)
    else:
        kuwo_playlist_download(url, info_only, **kwargs)


download = kuwo_download
download_playlist = kuwo_playlist_download



#!/usr/bin/env python

import re
import json

from lulu.common import (
    match1,
    url_info,
    print_info,
    get_content,
    download_urls,
    playlist_not_supported,
)
from lulu.extractors.universal import universal_download


__all__ = ['nanagogo_download']
site_info = '755 7gogo.jp'


def nanagogo_download(url, info_only=False, **kwargs):
    if re.match(r'https?://stat.7gogo.jp', url):
        universal_download(url, info_only=info_only, **kwargs)
        return

    talk_id = match1(url, r'7gogo.jp/([^/]+)/')
    post_id = match1(url, r'7gogo.jp/[^/]+/(\d+)')
    title = '{}_{}'.format(talk_id, post_id)
    api_url = 'https://api.7gogo.jp/web/v2/talks/{}/posts/{}'.format(
        talk_id, post_id
    )
    info = json.loads(get_content(api_url))

    items = []
    if info['data']['posts']['post'] is None:
        return
    if info['data']['posts']['post']['body'] is None:
        return
    for i in info['data']['posts']['post']['body']:
        if 'image' in i:
            image_url = i['image']
            if image_url[:2] == '//':
                continue  # skip stamp images
            _, ext, size = url_info(image_url)
            items.append({
                'title': title, 'url': image_url, 'ext': ext, 'size': size
            })
        elif 'movieUrlHq' in i:
            movie_url = i['movieUrlHq']
            _, ext, size = url_info(movie_url)
            items.append({
                'title': title, 'url': movie_url, 'ext': ext, 'size': size
            })

    size = sum([i['size'] for i in items])
    if size == 0:
        return  # do not fail the whole process
    print_info(site_info, title, ext, size)
    if not info_only:
        for i in items:
            print_info(site_info, i['title'], i['ext'], i['size'])
            download_urls(
                [i['url']], i['title'], i['ext'], i['size'], **kwargs
            )


download = nanagogo_download
download_playlist = playlist_not_supported(site_info)
